@@ -1,23 +1,19 @@
-
-from __future__ import print_function, division, absolute_import
-from keras.callbacks import EarlyStopping, ReduceLROnPlateau
-from keras.layers import Embedding, Dense, Dropout, Input, Reshape, Concatenate, BatchNormalization
-from keras.models import Model
-from keras.optimizers import Adam
-import logging
+from logging import getLogger
 import numpy as np
 from scipy import sparse
 from sklearn import base
-from sklearn.metrics import roc_auc_score
 from sklearn.model_selection import KFold
 import pandas as pd
-import tensorflow as tf
+from tensorflow.keras.callbacks import EarlyStopping, ReduceLROnPlateau
+from tensorflow.keras.layers import Embedding, Dense, Dropout, Input, Reshape, Concatenate, BatchNormalization
+from tensorflow.keras.metrics import AUC
+from tensorflow.keras.models import Model
+from tensorflow.keras.optimizers import Adam
 
-from .const import NAN_INT, MIN_EMBEDDING
+from .const import EMBEDDING_SUFFIX, MIN_EMBEDDING, NAN_INT
 
 
-logger = logging.getLogger('Kaggler')
-EMBEDDING_SUFFIX = '_emb'
+logger = getLogger(__name__)
 kfold = KFold(n_splits=5, shuffle=True, random_state=42)
 
 
@@ -131,7 +127,7 @@ class LabelEncoder(base.BaseEstimator):
 
             X.loc[:, col] = (X[col].fillna(NAN_INT)
                              .map(self.label_encoders[i])
-                             .fillna(0))
+                             .fillna(0).astype(int))
 
         return X
 
@@ -301,7 +297,8 @@ class TargetEncoder(base.BaseEstimator):
             else:
                 self.target_encoders[i] = []
                 for i_cv, (i_trn, i_val) in enumerate(self.cv.split(X[col], y), 1):
-                    self.target_encoders[i].append(self._get_target_encoder(X.loc[i_trn, col], y[i_trn]))
+                    i_trn, i_val = X.index[i_trn], X.index[i_val]
+                    self.target_encoders[i].append(self._get_target_encoder(X.loc[i_trn, col], y.loc[i_trn]))
 
         return self
 
@@ -353,6 +350,7 @@ class TargetEncoder(base.BaseEstimator):
             else:
                 self.target_encoders[i] = []
                 for i_cv, (i_trn, i_val) in enumerate(self.cv.split(X[col], y), 1):
+                    i_trn, i_val = X.index[i_trn], X.index[i_val]
                     target_encoder = self._get_target_encoder(X.loc[i_trn, col], y[i_trn])
 
                     X.loc[i_val, col] = (X.loc[i_val, col].fillna(NAN_INT)
@@ -407,10 +405,6 @@ class EmbeddingEncoder(base.BaseEstimator):
 
         self.lbe = LabelEncoder(min_obs=self.min_obs)
 
-    @staticmethod
-    def auc(y, p):
-        return tf.py_function(roc_auc_score, (y, p), tf.double)
-
     @staticmethod
     def _get_model(X, cat_cols, num_cols, n_uniq, n_emb, output_activation):
         inputs = []
@@ -469,7 +463,7 @@ class EmbeddingEncoder(base.BaseEstimator):
             assert np.isin(y, [0, 1]).all(), 'Target values should be 0 or 1 for classification.'
             output_activation = 'sigmoid'
             loss = 'binary_crossentropy'
-            metrics = [self.auc]
+            metrics = [AUC()]
             monitor = 'val_auc'
             mode = 'max'
         else:
@@ -484,15 +478,16 @@ class EmbeddingEncoder(base.BaseEstimator):
             self.embs = []
             n_fold = self.cv.get_n_splits(X)
             for i_cv, (i_trn, i_val) in enumerate(self.cv.split(X, y), 1):
+                i_trn, i_val = X.index[i_trn], X.index[i_val]
                 model, self.n_emb, _ = self._get_model(X_cat, self.cat_cols, self.num_cols, n_uniq, self.n_emb,
                                                        output_activation)
                 model.compile(optimizer=Adam(lr=0.01), loss=loss, metrics=metrics)
 
-                features_trn = [X_cat[col][i_trn] for col in self.cat_cols]
-                features_val = [X_cat[col][i_val] for col in self.cat_cols]
+                features_trn = [X_cat.loc[i_trn, col] for col in self.cat_cols]
+                features_val = [X_cat.loc[i_val, col] for col in self.cat_cols]
                 if self.num_cols:
-                    features_trn += [X[self.num_cols].values[i_trn]]
-                    features_val += [X[self.num_cols].values[i_val]]
+                    features_trn += [X.loc[i_trn, self.num_cols]]
+                    features_val += [X.loc[i_val, self.num_cols]]
 
                 es = EarlyStopping(monitor=monitor, min_delta=.001, patience=5, verbose=1, mode=mode,
                                    baseline=None, restore_best_weights=True)
@@ -600,7 +595,7 @@ class FrequencyEncoder(base.BaseEstimator):
             else:
                 self.frequency_encoders[i] = []
                 for i_cv, (i_trn, i_val) in enumerate(self.cv.split(X[col]), 1):
-                    self.frequency_encoders[i].append(self._get_frequency_encoder(X.loc[i_trn, col]))
+                    self.frequency_encoders[i].append(self._get_frequency_encoder(X.iloc[i_trn][col]))
 
         return self
 
@@ -644,6 +639,7 @@ class FrequencyEncoder(base.BaseEstimator):
             else:
                 self.frequency_encoders[i] = []
                 for i_cv, (i_trn, i_val) in enumerate(self.cv.split(X[col]), 1):
+                    i_trn, i_val = X.index[i_trn], X.index[i_val]
                     frequency_encoder = self._get_frequency_encoder(X.loc[i_trn, col])
 
                     X.loc[i_val, col] = X.loc[i_val, col].fillna('NaN').map(frequency_encoder).fillna(0)
